bayespy.inference.vmp.nodes.node.Moments.add_converter
======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.node

.. automethod:: Moments.add_converter